==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp5/postgresql12_SUSE-SU-2023_3341-1_sles_12.5.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for postgresql12 SUSE-SU-2023:3341-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2023-August/015942.html
# Source:      Security Announcement Generator (sagen.py) v2.0.13
# Modified:    2023 Aug 31
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "postgresql12"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2023-August/015942.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = False
	name = 'postgresql12'
	main = ''
	severity = 'Moderate'
	tag = 'SUSE-SU-2023:3341-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 12):
		if ( server['DistroPatchLevel'] == 5 ):
			packages = {
				'postgresql12': '12.16-3.42.1',
				'postgresql12-contrib': '12.16-3.42.1',
				'postgresql12-contrib-debuginfo': '12.16-3.42.1',
				'postgresql12-debuginfo': '12.16-3.42.1',
				'postgresql12-debugsource': '12.16-3.42.1',
				'postgresql12-plperl': '12.16-3.42.1',
				'postgresql12-plperl-debuginfo': '12.16-3.42.1',
				'postgresql12-plpython': '12.16-3.42.1',
				'postgresql12-plpython-debuginfo': '12.16-3.42.1',
				'postgresql12-pltcl': '12.16-3.42.1',
				'postgresql12-pltcl-debuginfo': '12.16-3.42.1',
				'postgresql12-server': '12.16-3.42.1',
				'postgresql12-server-debuginfo': '12.16-3.42.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp5/postgresql12_SUSE-SU-2023_2200-1_sles_12.5.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for postgresql12 SUSE-SU-2023:2200-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP5
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2023-May/014891.html
# Source:      Security Announcement Generator (sagen.py) v2.0.6
# Modified:    2023 Jun 13
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "postgresql12"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2023-May/014891.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = False
	name = 'postgresql12'
	main = ''
	severity = 'Important'
	tag = 'SUSE-SU-2023:2200-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 12):
		if ( server['DistroPatchLevel'] == 5 ):
			packages = {
				'postgresql12': '12.15-3.39.1',
				'postgresql12-contrib': '12.15-3.39.1',
				'postgresql12-contrib-debuginfo': '12.15-3.39.1',
				'postgresql12-debuginfo': '12.15-3.39.1',
				'postgresql12-debugsource': '12.15-3.39.1',
				'postgresql12-plperl': '12.15-3.39.1',
				'postgresql12-plperl-debuginfo': '12.15-3.39.1',
				'postgresql12-plpython': '12.15-3.39.1',
				'postgresql12-plpython-debuginfo': '12.15-3.39.1',
				'postgresql12-pltcl': '12.15-3.39.1',
				'postgresql12-pltcl-debuginfo': '12.15-3.39.1',
				'postgresql12-server': '12.15-3.39.1',
				'postgresql12-server-debuginfo': '12.15-3.39.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()
